@@ -1,8 +1,8 @@
 from bergen.messages.postman.assign.assign_cancelled import AssignCancelledMessage
-from bergen.messages.postman.progress import ProgressLevel
+from bergen.messages.postman.log import LogLevel
 from bergen.debugging import DebugLevel
 from bergen.handlers.base import ContractHandler
-from bergen.messages import BouncedForwardedAssignMessage, AssignYieldsMessage, AssignProgressMessage, AssignDoneMessage, AssignReturnMessage, AssignCriticalMessage
+from bergen.messages import BouncedForwardedAssignMessage, AssignYieldsMessage, AssignLogMessage, AssignDoneMessage, AssignReturnMessage, AssignCriticalMessage
 from bergen.console import console
 
 
@@ -12,16 +12,16 @@ class AssignHandler(ContractHandler[BouncedForwardedAssignMessage]):
     def meta(self):
         return {"extensions": self.message.meta.extensions, "reference": self.message.meta.reference}
 
-    async def log(self, message, level =ProgressLevel.INFO):
+    async def log(self, message, level =LogLevel.INFO):
         console.log(message)
-        await self.pass_progress(str(message), level=level)
+        await self.pass_log(str(message), level=level)
 
     async def pass_yield(self, value):
         yield_message = AssignYieldsMessage(data={"returns": value}, meta=self.meta)
         await self.forward(yield_message)
 
-    async def pass_progress(self, message: str, level: ProgressLevel = ProgressLevel.INFO):
-        progress_message = AssignProgressMessage(data={"message": message, "level": level.value}, meta=self.meta)
+    async def pass_log(self, message: str, level: LogLevel = LogLevel.INFO):
+        progress_message = AssignLogMessage(data={"message": message, "level": level.value}, meta=self.meta)
         await self.forward(progress_message)
 
     async def pass_done(self):
