@@ -89,7 +89,7 @@ class TypedGQL(GQL, Generic[MyType]):
     async def run(self, ward=None, variables=None, **kwargs) -> MyType:
         ward = ward or self._cls.get_ward()
         returnedobject = await ward.run(self, variables=variables, **kwargs)
-        assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
+        assert returnedobject is not None, f"We received nothing back from the Server! Refine your Query! Query: {self.query} Variables: {variables}"
         if isinstance(returnedobject,list): return ListQuery([self.cls(**item) for item in returnedobject])
         return self.cls(**returnedobject)
 
