@@ -26,12 +26,16 @@ class ArnheimModelManager(BaseManager, Generic[ModelType]):
         super().__init__()
 
     def _call_meta(self, attribute, **kwargs):
+        from bergen.registries.client import get_current_client
+        client = get_current_client()
         from bergen.types.utils import parse_kwargs
         method =  getattr(self.meta, attribute, None)
         assert method is not None, f"Please provide the {attribute} parameter in your ArnheimModel meta class "
-        typed_gql: TypedGQL = method(self.model) 
-        loop = asyncio.get_event_loop()
-        return loop.run_until_complete(typed_gql.run(variables=parse_kwargs(kwargs)))
+        typed_gql: TypedGQL = method(self.model)
+        if client.loop.is_running():
+            return asyncio.run_coroutine_threadsafe(typed_gql.run(variables=parse_kwargs(kwargs)), client.loop).result()
+        else:
+            return client.loop.run_until_complete(typed_gql.run(variables=parse_kwargs(kwargs)))
 
     def __getattr__(self, name: str) -> ModelType:
         def function(**kwargs):
