@@ -41,7 +41,7 @@ class AIOHttpGraphQLWard(ServiceWard):
                 response = await self.async_transport.execute(query_node, variable_values=variables)#
                 logger.debug(f"Received Reply {response}")
             except Exception as e:
-                console.print_exception()
+                console.print_exception(show_locals=True)
                 raise TokenExpired(f"Token Expired {e}")
                 
             if response.errors:
